@@ -4,7 +4,10 @@ from cytra.auth import AuthAppMixin
 
 
 class CytraAppBase(GongishApp):
-    # todo: database error handler
+    # Reserved CORS config
+    _cors_allow_methods: set = None
+    _cors_allow_headers: set = None
+    _cors_expose_headers: set = None
 
     @staticmethod
     def format_json(request, response, indent=None):
@@ -17,7 +20,9 @@ class CytraAppBase(GongishApp):
     __default_formatter__ = format_json
 
     def setup(self):
-        pass
+        self._cors_allow_methods = set()
+        self._cors_allow_headers = set(("content-type",))
+        self._cors_expose_headers = set(("content-type",))
 
     def shutdown(self):
         pass
