@@ -17,11 +17,13 @@ class AuthAppMixin:
         super().on_begin_request()
 
     def setup(self):
+        super().setup()
         if "auth" in self.config:
             self.auth = self.__authenticator__(app=self)
+            self._cors_allow_headers.update(("authorization",))
+            self._cors_expose_headers.update(("x-new-jwt-token",))
         else:
             self.auth = None
-        super().setup()
 
     def shutdown(self):
         if self.auth is not None:
